@@ -12,6 +12,11 @@ from fast_tracker.common.span_enum import SpanType, SpanLayerAtrr
 
 class MessageTrace(CatHeaderMixin, TimeTrace):
 
+    cat_id_key = 'fastID'
+    cat_transaction_key = 'fastTransaction'
+    cat_appdata_key = 'fastAppData'
+    cat_synthetics_key = 'fastSynthetics'
+
     def __init__(self, library, operation, destination_type, destination_name, params=None,
                  span_type=SpanType.Local.value,
                  span_layer=SpanLayerAtrr.MQ.value,
