@@ -29,10 +29,12 @@ from fast_tracker.core.attribute_filter import (DST_NONE, DST_ERROR_COLLECTOR,
 from fast_tracker.core.config import DEFAULT_RESERVOIR_SIZE
 from fast_tracker.core.custom_event import create_custom_event
 from fast_tracker.core.stack_trace import exception_stack
-from fast_tracker.common.encoding_utils import (generate_path_hash,
+from fast_tracker.common.encoding_utils import (generate_path_hash, obfuscate,
+                                                deobfuscate, json_encode, json_decode, base64_decode,
                                                 convert_to_cat_metadata_value, DistributedTracePayload, ensure_str,
                                                 W3CTraceParent, W3CTraceState, NrTraceState)
 from fast_tracker.common.span_enum import SpanType, SpanLayerAtrr
+from fast_tracker.common.utils import seq_id
 
 from fast_tracker.api.time_trace import TimeTrace
 
@@ -203,7 +205,7 @@ class Transaction(object):
 
         self.rum_token = None
 
-        trace_id = ''  # TODO trace_id的入口
+        trace_id = seq_id()  # TODO trace_id的入口
         self.guid = ''
         self._trace_id = trace_id
 
@@ -848,6 +850,7 @@ class Transaction(object):
             if not any(k in data for k in ('id', 'tx')):
                 return False
 
+            settings = self._settings
             try:
                 data['ti'] = int(data['ti'])
             except:
@@ -908,7 +911,7 @@ class Transaction(object):
         try:
             traceparent = headers.get('traceparent', '')
             tracestate = headers.get('tracestate', '')
-            distributed_header = headers.get('fast-tracker', '')
+            distributed_header = headers.get('fast', '')
         except Exception:
             traceparent = ''
             tracestate = ''
@@ -920,7 +923,7 @@ class Transaction(object):
                     traceparent = v
                 elif k == 'tracestate':
                     tracestate = v
-                elif k == 'fast-tracker':
+                elif k == 'fast':
                     distributed_header = v
 
         if traceparent:
@@ -963,28 +966,91 @@ class Transaction(object):
 
     def _process_incoming_cat_headers(self, encoded_cross_process_id,
                                       encoded_txn_header):
-        """
-        不支持跨应用监控
-        :param encoded_cross_process_id:
-        :param encoded_txn_header:
-        :return:
-        """
-        pass
+        settings = self._settings
+
+        if not self.enabled:
+            return
+
+        if not (settings.cross_application_tracer.enabled and
+                settings.cross_process_id and settings.encoding_key):
+            return
+
+        if encoded_cross_process_id is None:
+            return
+
+        try:
+            client_cross_process_id = deobfuscate(
+                encoded_cross_process_id, settings.encoding_key)
+            client_account_id, client_application_id = \
+                map(int, client_cross_process_id.split('#'))
+            self.client_cross_process_id = client_cross_process_id
+            self.client_account_id = client_account_id
+            self.client_application_id = client_application_id
+
+            txn_header = json_decode(deobfuscate(
+                encoded_txn_header,
+                settings.encoding_key))
+
+            if txn_header:
+                self.is_part_of_cat = True
+                self.referring_transaction_guid = txn_header[0]
+
+                self.record_tt = (self.record_tt or
+                                  txn_header[1])
+
+                if isinstance(txn_header[2], six.string_types):
+                    self._trip_id = txn_header[2]
+                if isinstance(txn_header[3], six.string_types):
+                    self._referring_path_hash = txn_header[3]
+        except Exception:
+            pass
 
     def _generate_response_headers(self, read_length=None):
-        """
+        nr_headers = []
 
-        :param read_length:
-        :return:
-        """
-        return []
+        if self.client_cross_process_id is not None:
+
+            if self.queue_start:
+                queue_time = self.start_time - self.queue_start
+            else:
+                queue_time = 0
+
+            if self.end_time:
+                duration = self.end_time - self.start_time
+            else:
+                duration = time.time() - self.start_time
+
+            self._freeze_path()
+
+            if read_length is None:
+                read_length = self._read_length
+
+            read_length = read_length if read_length is not None else -1
+
+            payload = (self._settings.cross_process_id, self.path, queue_time,
+                       duration, read_length, self.guid, self.record_tt)
+            app_data = json_encode(payload)
+
+            nr_headers.append(('X-fast-App-Data', obfuscate(
+                app_data, self._settings.encoding_key)))
+
+        return nr_headers
 
     def get_response_metadata(self):
         nr_headers = dict(self._generate_response_headers())
         return convert_to_cat_metadata_value(nr_headers)
 
     def process_request_metadata(self, cat_linking_value):
-        return
+        try:
+            payload = base64_decode(cat_linking_value)
+        except:
+            return
+
+        nr_headers = json_decode(payload)
+        encoded_cross_process_id = nr_headers.get('X-fast-ID')
+        encoded_txn_header = nr_headers.get('X-fast-Transaction')
+        return self._process_incoming_cat_headers(encoded_cross_process_id,
+                                                  encoded_txn_header)
 
     def set_transaction_name(self, name, group=None, priority=None):
 
