@@ -173,12 +173,8 @@ class Agent(object):
         """
 
         if not self._config.enabled:
-            logging.info('探针启动配置是关闭的,探针代理初始化失败')
             return
         settings = fast_tracker.core.config.global_settings()
-        if not settings.product_code or not settings.app_code:
-            logging.info('没有配置产品编码或者应用编码,探针代理初始化失败')
-            return
         if timeout is None:
             if settings.serverless_mode.enabled:
                 timeout = 10.0
@@ -389,7 +385,7 @@ class Agent(object):
                 _logger.debug('收集线程被禁止.')
                 return
 
-            if self._harvest_thread.is_alive():  # python3.9没有这个属性
+            if self._harvest_thread.isAlive():
                 return
 
             _logger.debug('正在激活代理实例.')
