@@ -200,10 +200,6 @@ class LogServerSettings(Settings):
     pass
 
 
-class CarrierHeaderSettings(Settings):
-    pass
-
-
 _settings = Settings()
 _settings.attributes = AttributesSettings()
 _settings.transaction_tracer = TransactionTracerSettings()
@@ -244,15 +240,10 @@ _settings.event_harvest_config.harvest_limits = \
 
 _settings.transport = TransportSettings()
 _settings.log_server = LogServerSettings()
-_settings.carrier_header = CarrierHeaderSettings()
 
 _settings.log_file = os.environ.get('FAST_LOG', 'logs/fast-tracker/{Date}.log')
 _settings.audit_log_file = os.environ.get('FAST_AUDIT_LOG', 'logs/fast-tracker/{Date}.log')
 
-# 请求头
-_settings.carrier_header.tracker_name = 'fast-tracker'
-_settings.carrier_header.tracker_id_name = 'x-fast-trace-id'
-
 
 def _environ_as_int(name, default=0):
     #  解析环境/配置文件变量为int类型
@@ -428,7 +419,7 @@ _settings.attributes.enabled = True
 _settings.attributes.exclude = []
 _settings.attributes.include = []
 
-_settings.cross_application_tracer.enabled = False
+_settings.cross_application_tracer.enabled = True
 
 _settings.transaction_events.enabled = True
 _settings.transaction_events.attributes.enabled = True
