@@ -3,29 +3,12 @@
 统计引擎是收集累计事物指标，错误详情，慢事物。 每个应用都有一个统计引擎示例。当成功收集的数据发送到核心应用后，它会被清空
 """
 
-import base64
 import copy
 import logging
 import operator
 import random
-import zlib
-import time
-import sys
 from heapq import heapreplace, heapify
 
-import fast_tracker.packages.six as six
-
-from fast_tracker.core.attribute_filter import DST_ERROR_COLLECTOR
-from fast_tracker.core.attribute import create_user_attributes
-
-from fast_tracker.core.attribute import process_user_attribute
-from fast_tracker.core.database_utils import explain_plan
-from fast_tracker.core.error_collector import TracedError
-from fast_tracker.core.metric import TimeMetric
-from fast_tracker.core.stack_trace import exception_stack
-
-from fast_tracker.api.settings import STRIP_EXCEPTION_MESSAGE
-from fast_tracker.common.encoding_utils import json_encode
 
 _logger = logging.getLogger(__name__)
 
