@@ -357,12 +357,7 @@ class TransactionNode(_TransactionNode):
 
     def span_events(self, settings):
         base_attrs = {
-            'id': self.trace_id,
-            'pc': settings.product_code,
-            'ac': settings.app_code,
-            'sn': settings.service_name,
-            'e':  settings.env_code,
-            'tn': settings.tenant_code
+            'id': self.trace_id
         }
         if hasattr(settings, 'thread_id_max_value'):
             thread_id_max_value = settings.thread_id_max_value
