@@ -1,11 +1,8 @@
 # -*- coding: utf-8 -*-
 
-
-import functools
-
 from fast_tracker.api.external_trace import ExternalTrace
-from fast_tracker.api.transaction import current_transaction
 from fast_tracker.common.object_wrapper import wrap_function_wrapper
+from fast_tracker.common.span_enum import SpanLayerAtrr, SpanType
 from fast_tracker.hooks.external_httplib2 import (
     _nr_wrapper_httplib2_endheaders_wrapper)
 
@@ -16,7 +13,7 @@ def _nr_wrapper_make_request_(wrapped, instance, args, kwargs):
 
     url_for_apm_ui = _bind_params(*args, **kwargs)
 
-    with ExternalTrace('urllib3', url_for_apm_ui):
+    with ExternalTrace('urllib3', url_for_apm_ui, span_type=SpanType.Exit.value, span_layer=SpanLayerAtrr.HTTP.value):
         return wrapped(*args, **kwargs)
 
 
